package com.zhyc.module.biosafety.mapper;

import java.util.List;
import com.zhyc.module.biosafety.domain.SwMedicine;
import org.apache.ibatis.annotations.Mapper;

/**
 * 药品Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-11
 */
@Mapper
public interface SwMedicineMapper 
{
    /**
     * 查询药品
     * 
     * @param id 药品主键
     * @return 药品
     */
    public SwMedicine selectSwMedicineById(Long id);

    /**
     * 查询药品列表
     * 
     * @param swMedicine 药品
     * @return 药品集合
     */
    public List<SwMedicine> selectSwMedicineList(SwMedicine swMedicine);

    /**
     * 新增药品
     * 
     * @param swMedicine 药品
     * @return 结果
     */
    public int insertSwMedicine(SwMedicine swMedicine);

    /**
     * 修改药品
     * 
     * @param swMedicine 药品
     * @return 结果
     */
    public int updateSwMedicine(SwMedicine swMedicine);

    /**
     * 删除药品
     * 
     * @param id 药品主键
     * @return 结果
     */
    public int deleteSwMedicineById(Long id);

    /**
     * 批量删除药品
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSwMedicineByIds(Long[] ids);
}
