package com.zhyc.module.biosafety.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.zhyc.module.biosafety.domain.SwMedicine;
import com.zhyc.module.biosafety.service.ISwMedicineService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zhyc.common.annotation.Log;
import com.zhyc.common.core.controller.BaseController;
import com.zhyc.common.core.domain.AjaxResult;
import com.zhyc.common.enums.BusinessType;
import com.zhyc.common.utils.poi.ExcelUtil;
import com.zhyc.common.core.page.TableDataInfo;

/**
 * 药品Controller
 * 
 * @author ruoyi
 * @date 2025-07-11
 */
@RestController
@RequestMapping("/biosafety/medicine")
public class SwMedicineController extends BaseController
{
    @Autowired
    private ISwMedicineService swMedicineService;

    /**
     * 查询药品列表
     */
    @PreAuthorize("@ss.hasPermi('biosafety:medicine:list')")
    @GetMapping("/list")
    public TableDataInfo list(SwMedicine swMedicine)
    {
        startPage();
        List<SwMedicine> list = swMedicineService.selectSwMedicineList(swMedicine);
        return getDataTable(list);
    }

    /**
     * 导出药品列表
     */
    @PreAuthorize("@ss.hasPermi('biosafety:medicine:export')")
    @Log(title = "药品", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SwMedicine swMedicine)
    {
        List<SwMedicine> list = swMedicineService.selectSwMedicineList(swMedicine);
        ExcelUtil<SwMedicine> util = new ExcelUtil<SwMedicine>(SwMedicine.class);
        util.exportExcel(response, list, "药品数据");
    }

    /**
     * 获取药品详细信息
     */
    @PreAuthorize("@ss.hasPermi('biosafety:medicine:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(swMedicineService.selectSwMedicineById(id));
    }

    /**
     * 新增药品
     */
    @PreAuthorize("@ss.hasPermi('biosafety:medicine:add')")
    @Log(title = "药品", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SwMedicine swMedicine)
    {
        return toAjax(swMedicineService.insertSwMedicine(swMedicine));
    }

    /**
     * 修改药品
     */
    @PreAuthorize("@ss.hasPermi('biosafety:medicine:edit')")
    @Log(title = "药品", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SwMedicine swMedicine)
    {
        return toAjax(swMedicineService.updateSwMedicine(swMedicine));
    }

    /**
     * 删除药品
     */
    @PreAuthorize("@ss.hasPermi('biosafety:medicine:remove')")
    @Log(title = "药品", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(swMedicineService.deleteSwMedicineByIds(ids));
    }
}
